# frozen_string_literal: true

require 'zeitwerk'
require 'lhc'
require 'lhs'

inflections = {
  'api_key' => 'APIKey',
  'edm' => 'EDM'
}

loader = Zeitwerk::Loader.for_gem
loader.enable_reloading
loader.inflector.inflect(inflections)
loader.setup

module Netilion
  Config = Struct.new :environment, :api_key, :username, :password

  def self.configure(&config_block)
    config_block.call config
    set_api_placeholders
    config
  end

  def self.config
    @config ||= Config.new(environment: :production)
  end

  def self.api_base
    case config.environment
    when :production
      'https://api.netilion.endress.com'
    when :staging
      'https://api.staging-env.netilion.endress.com'
    when :local
      'http://localhost:3000'
    end
  end

  def self.set_api_placeholders
    LHC.configure do |config|
      config.placeholder(:api, "#{api_base}/v1")
      config.placeholder(:edm, "#{api_base}/v1/edm")

      config.interceptors = [
        Authentication,
        LHC::Auth,
        LHC::Caching
      ]
    end
  end
end
